import { world, system, EquipmentSlot, Player } from "@minecraft/server";
import { ActionFormData, ModalFormData } from "@minecraft/server-ui";

system.runInterval(() => {
    if (!!world.getDynamicProperty('autoTotem'))
        autoOffhandTotem();
    if (!!world.getDynamicProperty('autoCrystal'))

        world.getDimension('overworld').runCommand('event entity @e[type=ender_crystal] minecraft:crystal_explode')
}, 1);

function autoOffhandTotem() {
    const players = world.getPlayers();
    players.forEach((player) => {
        const inventory = player.getComponent('inventory').container;
        const equipmentInventory = player.getComponent('equippable')
        const offHand = equipmentInventory.getEquipment(EquipmentSlot.Offhand)
        if (!offHand) {
            const invSize = inventory.size;
            for (let index = 0; index < invSize; index++) {
                const item = inventory.getItem(index);
                if (item && item.typeId === 'minecraft:totem_of_undying') {
                    inventory.setItem(index)
                    equipmentInventory.setEquipment(EquipmentSlot.Offhand, item);
                    return;
                }
            }
        }
    })

}

world.beforeEvents.itemUse.subscribe(data => {
    if (data.source.hasTag('admin')) {
        if (data.itemStack && data.itemStack.typeId === 'minecraft:totem_of_undying') {
            system.run(() => openSettings(data.source));
        }
    }
})

world.afterEvents.worldInitialize.subscribe(data => {
    system.runTimeout(() => {
        const autoTotem = world.getDynamicProperty('autoTotem');
        if (autoTotem === undefined) world.setDynamicProperty('autoTotem', false);
        const autoCrystal = world.getDynamicProperty('autoCrystal');
        if (autoCrystal === undefined) world.setDynamicProperty('autoCrystal', false);
        const autoTnt = world.getDynamicProperty('autoTnt');
        if (autoTnt === undefined) world.setDynamicProperty('autoTnt', false);

    })
})

/**
 * 
 * @param {Player} player 
*/
async function openSettings(player) {
    const autoTnt = !!world.getDynamicProperty('autoTnt');
    const autoTotem = !!world.getDynamicProperty('autoTotem');
    const autoCrystal = !!world.getDynamicProperty('autoCrystal');
    const form = new ModalFormData()
        .title('PVP+ Menüsü')
        .toggle('Oto Totem Özelliği', autoTotem)
        .toggle('Oto Kristal Patlama', autoCrystal)
        .toggle('Oto TNT Patlama', autoTnt)
        .submitButton('§0Kaydet§r')
        .show(player).then((r) => {
            if (r.canceled || !r.formValues) return;

            world.setDynamicProperty('autoTotem', r.formValues[0]);
            if (r.formValues[0]) {
                player.sendMessage(`§aOto Totem Özelliği Aktif Edildi!`);
            } else
                player.sendMessage(`§eOto Totem Özelliği Deaktif Edildi!`);

            world.setDynamicProperty('autoCrystal', r.formValues[1]);
            if (r.formValues[1]) {
                player.sendMessage(`§aOto Kristal Patlama Aktif Edildi!`);
            } else
                player.sendMessage(`§eOto Kristal Patlama Deaktif Edildi!`);

            world.setDynamicProperty('autoTnt', r.formValues[2]);
            if (r.formValues[2]) {
                player.sendMessage(`§aOto TNT Patlama Aktif Edildi!`);
            } else
                player.sendMessage(`§eOto TNT Patlama Deaktif Edildi!`);
        })
}

world.afterEvents.playerPlaceBlock.subscribe(data => {
    const { dimension, player, block } = data;
    if (!!world.getDynamicProperty('autoTnt'))
        if (block.typeId === 'minecraft:tnt') {

            const { x, y, z } = block.location;

            system.run(() => {
                dimension.getBlock(block.location).setType('minecraft:air')
                dimension.spawnEntity('minecraft:tnt', { x: x + 0.5, y: y + 0.1, z: z + 0.5 })
            })
        }

})